#ifndef __SERIAL_H
#define __SERIAL_H

#include <stdio.h>



void Serial_Init(void);
void Serial_SendByte(uint8_t Byte);
void Serial_SendArray(uint8_t *Array, uint16_t Length);
void Serial_SendString(char *String);
void Serial_SendNumber(uint32_t Number, uint8_t Length);
void Serial_Printf(char *format, ...);
void USART1_SendNumber(int number);

uint8_t Serial_GetRxFlag(void);
char Serial_GetRxData(void);
void Serial_ReceivedData(char *buffer);

extern uint8_t Serial_RxPacket[];
extern uint8_t Serial_RxFlag;
extern uint8_t Serial_TxPacket[];
void Serial_SendPacket(void);


#endif
